==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/es.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ha habilitado la autenticación de dos factores TOTP para su cuenta",
    "You disabled TOTP two-factor authentication for your account" : "Ha deshabilitado la autenticación de dos factores TOTP para su cuenta",
    "TOTP two-factor authentication disabled by the administration" : "La autenticación de dos factores TOTP ha sido desactivada por la administración",
    "TOTP (Authenticator app)" : "TOTP (App de autenticación)",
    "Authenticate with a TOTP app" : "Autenticar con la app TOTP",
    "Two-Factor TOTP Provider" : "Proveedor de autenticación de dos factores TOTP",
    "Two-factor TOTP provider" : "Proveedor de segundo factor TOTP",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Un proveedor de autenticación en dos pasos para TOTP (RFC 6238)",
    "Could not enable TOTP" : "No se ha podido activar TOTP",
    "Could not verify your key. Please try again" : "No se ha podido verificar su clave. Por favor, inténtelo de nuevo",
    "Enable TOTP" : "Habilitar TOTP",
    "Your new TOTP secret is:" : "Este es tu nuevo secreto TOTP:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para una configuración rápida, escanea este código QR con tu app TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Una vez has configurado la aplicación, introduce un código de prueba debajo para asegurarte de que tu aplicación se ha configurado correctamente.",
    "Authentication code" : "Código de autentificación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Consigue el código de autenticación de dos factores en la aplicación de tu dispositivo móvil.",
    "Submit" : "Enviar",
    "TOTP two-factor authentication disabled by an admin" : "La autenticación de dos factores TOTP ha sido desactivada por un administrador",
    "TOTP two-factor provider" : "Proveedor de TOTP para autenticación de dos factores",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un proveedor de autenticación de dos factores para TOTP (RFC 6238)"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/es.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ha habilitado la autenticación de dos factores TOTP para su cuenta",
    "You disabled TOTP two-factor authentication for your account" : "Ha deshabilitado la autenticación de dos factores TOTP para su cuenta",
    "TOTP two-factor authentication disabled by the administration" : "La autenticación de dos factores TOTP ha sido desactivada por la administración",
    "TOTP (Authenticator app)" : "TOTP (App de autenticación)",
    "Authenticate with a TOTP app" : "Autenticar con la app TOTP",
    "Two-Factor TOTP Provider" : "Proveedor de autenticación de dos factores TOTP",
    "Two-factor TOTP provider" : "Proveedor de segundo factor TOTP",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Un proveedor de autenticación de dos factores para TOTP (RFC 6238)",
    "Could not enable TOTP" : "No se ha podido activar TOTP",
    "Could not verify your key. Please try again" : "No se ha podido verificar su clave. Por favor, inténtelo de nuevo",
    "Enable TOTP" : "Habilitar TOTP",
    "Your new TOTP secret is:" : "Este es tu nuevo secreto TOTP:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para una configuración rápida, escanea este código QR con tu app TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Una vez has configurado la aplicación, introduce un código de prueba debajo para asegurarte de que tu aplicación se ha configurado correctamente.",
    "Authentication code" : "Código de autentificación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Consigue el código de autenticación de dos factores en la aplicación de tu dispositivo móvil.",
    "Submit" : "Enviar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
